==> 1.7.tar.gz: 1.7/variablen.php <==
<?php
  $message = array(
    'link_erstellen' => "Link erstellen",
    'gespeichert1' => "<br />Nachricht erfolgreich gespeichert.<br />Die Nachricht kann nun <b>einmal</b> mit <br />folgendem Link gelesen werden:<br /><br />",
    'hinweis' => "Kopiere diesen Link in den<br />Messenger Deiner Wahl.",
    'clipboard' => "Link in die Zwischenablage kopieren.",
    'link_weitere' => "weitere Nachricht schreiben.<br /><br />",
    'neue_Nachricht' => "<br />Du hast eine Nachricht, <br />jetzt anzeigen.",
    'keine_Nachricht' => "<br />Es gibt keine ungelesene<br /> Nachricht mehr.",
    'zu_spaet' => "Die Nachricht wurde schon angezeigt<br />und gel&ouml;scht.",
    'headline' => "<h3><u>secnote.eblok.de</u></h3>",
    'anleitung' => "<h4>Bitte eine Nachricht eingeben.</h4>
    			Nach erstellen der Nachricht wird ein Link angezeigt.<br />
    			Dieser kann dann, in einen Messenger nach Wahl oder per E-Mail, versendet werden.<br />
    			Die Nachricht kann nur einmal mit dem Link angezeigt werden, dabei wird die Nachricht gel&ouml;scht.<br /><br />",
    'selbstNachricht' => "Selbst eine Nachricht erstellen.",
    'abschaltung' => "<br />Diese Seite wird abgeschaltet.<br /><br />Es k&ouml;nnen keine Nachrichten mehr geschrieben werden.<br /><br />",
    'passworthinweisSender' => "Dieses Passwort muss der Empf&auml;nger kennen<br />zum entschl&uuml;sseln der Nachricht!",
    'passworthinweisEmpf' => "<br />Du MUSST das Passwort kennen!<br />&Uuml;berpr&uuml;fe selbst ob Du alles richtig eingegeben hast!<br />",
    'zeigen' => "Anzeigen",
    'empfaengerhinweis' => "<br />Der Absender hat ein Passwort eingegeben.<br />
    Es muss richtig sein, sonst kann die Nachricht<br />nicht richtig angezeigt werden.<br /><br />",
    'geloescht' => "<hr />Die Nachricht wurde gel&ouml;scht",
  );
  $config = array(
    'version' => "1.7",
    'clientDelTime' => "3",
    'userDelDays' => "3",
    'codelenght' => "8",
    'Passwortfehlversuche' => "1",
  );
?>

==> 2.0.tar.gz: 2.0/variablen.php <==
<?php
  $message = array(
    'link_erstellen' => "Link erstellen",
    'hinweis' => "Kopiere diesen Link in den<br />Messenger Deiner Wahl.",
    'clipboard' => "Link in die Zwischenablage kopieren.",
    'link_weitere' => "weitere Nachricht schreiben.<br /><br />",
    'neue_Nachricht' => "<br />Du hast eine Nachricht, <br />jetzt anzeigen.",
    'keine_Nachricht' => "<br />Es gibt keine ungelesene<br /> Nachricht mehr.",
    'zu_spaet' => "Die Nachricht wurde schon angezeigt<br />und gel&ouml;scht.",
    'headline' => "<h3><u>secnote.eblok.de</u></h3>",
    'anleitung' => "<h4>Bitte eine Nachricht eingeben.</h4>
    			Nach erstellen der Nachricht wird ein Link angezeigt.<br />
    			Dieser kann dann, in einen Messenger nach Wahl oder per E-Mail, versendet werden.<br />
    			Die Nachricht kann nur einmal mit dem Link angezeigt werden, dabei wird die Nachricht gel&ouml;scht.<br /><br />",
    'selbstNachricht' => "Selbst eine Nachricht erstellen.",
    'abschaltung' => "<br />Diese Seite wird abgeschaltet.<br /><br />Es k&ouml;nnen keine Nachrichten mehr geschrieben werden.<br /><br />",
    'passworthinweisSender' => "Dieses Passwort muss der Empf&auml;nger kennen<br />zum entschl&uuml;sseln der Nachricht!",
    'passworthinweisEmpf' => "<br />Du MUSST das Passwort kennen!<br />&Uuml;berpr&uuml;fe selbst ob Du alles richtig eingegeben hast!<br />",
    'zeigen' => "Anzeigen",
    'empfaengerhinweis' => "<br />Der Absender hat ein Passwort eingegeben.<br />
    Es muss richtig sein, sonst kann die Nachricht<br />nicht richtig angezeigt werden.<br /><br />",
    'geloescht' => "<hr />Die Nachricht wurde gel&ouml;scht",
    'bild_label' => "Bild anhaengen (max. 5 MB)",
    'bild_zu_gross' => "Das Bild ist zu gross (max. 5 MB).",
    'bild_ungueltig' => "Nur Bilddateien (JPG, PNG, GIF, WEBP) sind erlaubt.",
    'eingabe_leer' => "Bitte Text eingeben oder ein Bild anhaengen.",
  );
  $config = array(
    'version' => "1.5",
    'salt' => "hkHT456jkjidfghjtzrdf65454tgsdlp",
    'clientDelTime' => "3",
    'userDelDays' => "3",
    'codelenght' => "8",
    'Passwortfehlversuche' => "1",
    'bild_upload' => true,
    'passwort_funktion' => true,
    'max_bild_size' => 5 * 1024 * 1024,
  );
?>
